summaryrefslogtreecommitdiff
path: root/java/com/android/incallui/VideoCallPresenter.java
diff options
context:
space:
mode:
Diffstat (limited to 'java/com/android/incallui/VideoCallPresenter.java')
-rw-r--r--java/com/android/incallui/VideoCallPresenter.java11
1 files changed, 8 insertions, 3 deletions
diff --git a/java/com/android/incallui/VideoCallPresenter.java b/java/com/android/incallui/VideoCallPresenter.java
index 5d2138ee0..31999ef2e 100644
--- a/java/com/android/incallui/VideoCallPresenter.java
+++ b/java/com/android/incallui/VideoCallPresenter.java
@@ -154,8 +154,8 @@ public class VideoCallPresenter
/**
* Determines if the incoming video surface should be shown based on the current videoState and
* callState. The video surface is shown when incoming video is not paused, the call is active,
* and video reception is enabled.
*
* @param videoState The current video state.
* @param callState The current call state.
@@ -168,8 +168,13 @@ public class VideoCallPresenter
boolean isPaused = VideoProfile.isPaused(videoState);
boolean isCallActive = callState == DialerCall.State.ACTIVE;
+ //Show incoming Video for dialing calls to support early media
+ boolean isCallOutgoingPending =
+ DialerCall.State.isDialing(callState) || callState == DialerCall.State.CONNECTING;
- return !isPaused && isCallActive && VideoProfile.isReceptionEnabled(videoState);
+ return !isPaused
+ && (isCallActive || isCallOutgoingPending)
+ && VideoProfile.isReceptionEnabled(videoState);
}
/**
@@ -154,8 +154,8 @@ public class VideoCallPresenter
/**
* Determines if the incoming video surface should be shown based on the current videoState and
- * callState. The video surface is shown when incoming video is not paused, the call is active,
- * and video reception is enabled.
+ * callState. The video surface is shown when incoming video is not paused, the call is active or
+ * dialing and video reception is enabled.
*
* @param videoState The current video state.